@@ -12,7 +12,7 @@
 //! }
 //!
 //! ```
-use serde::de::DeserializeOwned;
+use serde::{de::DeserializeOwned, Serialize};
 use std::{fs, io::Result};
 
 /// This trait represent anything that can be parsed from toml file
@@ -20,8 +20,9 @@ pub trait FromTomlFile {
     fn from_toml_file(filename: &str) -> Result<Self>
     where
         Self: Sized;
+    fn save_to_file(&self, filename: &str) -> Result<()>;
 }
-impl<T: DeserializeOwned> FromTomlFile for T {
+impl<T: DeserializeOwned + Serialize> FromTomlFile for T {
     /// Implementation of FromTomFile for any Deserializable data type
     fn from_toml_file(filename: &str) -> Result<Self> {
         let content = fs::read_to_string(filename)?;
@@ -29,15 +30,19 @@ impl<T: DeserializeOwned> FromTomlFile for T {
         let result: Self = toml::from_str(&content)?;
         Ok(result)
     }
+    fn save_to_file(&self, filename: &str) -> Result<()> {
+        let data = toml::to_string_pretty(&self).unwrap();
+        fs::write(filename, data)
+    }
 }
 
 #[cfg(test)]
 mod tests {
     use super::FromTomlFile;
-    use serde::Deserialize;
+    use serde::{Deserialize, Serialize};
     use std::fs;
 
-    #[derive(Deserialize, Debug, Default)]
+    #[derive(Deserialize, Serialize, Debug, Default)]
     #[serde(default)]
     struct Config {
         title: String,
